% a example to plot the PSD of time series data 
% with the Peterson's noise model
% Yuechu Wu
% 12131066@mail.sustech.edu.cn
% 2022-09-29

clear; close all;

samprate = 10; % Sampling rate
dt = 1/samprate;

t = 0:dt:3600;  % Time vector (1 hours)
t = t';  % Column vector
y = 3*sin(2*pi*1/5*t)+sin(2*pi*1/14*t)+2*rand(length(t),1)-1;  
y = 10^-7*y;  % Synthetic seismic noise (Unit: m)
[nlnm,nhnm] = noise_model('Peterson');

[freq,psd] = disp2psd(y,dt);

figure(1)
semilogx((1./freq),10*log10(psd),'color','#00688B','linewidth',2); hold on
semilogx(nlnm(:,1), nlnm(:,2),'k--','Linewidth',1);
semilogx(nhnm(:,1), nhnm(:,2),'k--','Linewidth',1);

xlim([1/max(freq) 250]);
ylim([-200 -80]);
xlabel('Period (s)');
ylabel('Power (dB), 10*log(m^{2}/s^{4}/Hz)');
grid on;

figure(2)
semilogx(freq,10*log10(psd),'color','#00688B','linewidth',2); hold on
semilogx(1./nlnm(:,1), nlnm(:,2),'k--','Linewidth',1);
semilogx(1./nhnm(:,1), nhnm(:,2),'k--','Linewidth',1);

xlim([1/250 max(freq)]);
ylim([-200 -80]);
xlabel('Frequency (Hz)');
ylabel('Power (dB), 10*log(m^{2}/s^{4}/Hz)');
grid on;